# lightkube-models

This is a python module containing definitions of kubernetes
models and resources to be used by [lightkube](https://lightkube.readthedocs.io/en/latest/).

The version of this package (first 3 parts `major.minor.micro`), match 
the kubernetes schema version used to generate the models.

You should install the module version matching your kubernetes installation or just
use compatible resources.
